==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/domain/usecases/promotion_get_promotions.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:equatable/equatable.dart';

class PromotionGetPromotions
    implements UseCase<dynamic, PromotionGetPromotionsParams> {
  final PromotionRepository repository;

  PromotionGetPromotions(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      PromotionGetPromotionsParams params) async {
    return await repository.getPromotions(
      start: params.start,
      limit: params.limit,
      categoryIds: params.categoryIds,
      storeIds: params.storeIds,
      retailerTokens: params.retailerTokens,
      companyTokens: params.companyTokens,
      textSearch: params.textSearch,
      zipcode: params.zipcode,
      latitude: params.latitude,
      longitude: params.longitude,
      radius: params.radius,
      orderBy: params.orderBy,
      publisherName: params.publisherName,
    );
  }
}

class PromotionGetPromotionsParams extends Equatable {
  final int start;
  final int limit;
  final List<String> categoryIds;
  final List<String> storeIds;
  final List<String> retailerTokens;
  final List<String> companyTokens;
  final String textSearch;
  final String zipcode;
  final String latitude;
  final String longitude;
  final String radius;
  final String orderBy;
  final String publisherName;

  PromotionGetPromotionsParams({
    this.start,
    this.limit,
    this.categoryIds,
    this.storeIds,
    this.retailerTokens,
    this.companyTokens,
    this.textSearch,
    this.zipcode,
    this.latitude,
    this.longitude,
    this.radius,
    this.orderBy,
    this.publisherName,
  });

  @override
  List<Object> get props => [
        start,
        limit,
        categoryIds,
        storeIds,
        retailerTokens,
        companyTokens,
        textSearch,
        zipcode,
        latitude,
        longitude,
        radius,
        orderBy,
        publisherName,
      ];
}

==> dcoupon_sdk_flutter_package-8.0.1.tar.gz: lib/src/domain/usecases/promotion_get_promotions.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:equatable/equatable.dart';

class PromotionGetPromotions
    implements UseCase<dynamic, PromotionGetPromotionsParams> {
  final PromotionRepository repository;

  PromotionGetPromotions(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      PromotionGetPromotionsParams params) async {
    return await repository.getPromotions(
      start: params.start,
      limit: params.limit,
      categoryIds: params.categoryIds,
      storeIds: params.storeIds,
      retailerTokens: params.retailerTokens,
      companyTokens: params.companyTokens,
      textSearch: params.textSearch,
      zipcode: params.zipcode,
      latitude: params.latitude,
      longitude: params.longitude,
      radius: params.radius,
      orderBy: params.orderBy,
      publisherToken: params.publisherToken,
    );
  }
}

class PromotionGetPromotionsParams extends Equatable {
  final int? start;
  final int? limit;
  final List<String>? categoryIds;
  final List<String>? storeIds;
  final List<String>? retailerTokens;
  final List<String>? companyTokens;
  final String? textSearch;
  final String? zipcode;
  final String? latitude;
  final String? longitude;
  final String? radius;
  final String? orderBy;
  final String publisherToken;

  PromotionGetPromotionsParams({
    this.start,
    this.limit,
    this.categoryIds,
    this.storeIds,
    this.retailerTokens,
    this.companyTokens,
    this.textSearch,
    this.zipcode,
    this.latitude,
    this.longitude,
    this.radius,
    this.orderBy,
    required this.publisherToken,
  });

  @override
  List<Object?> get props => [
        start,
        limit,
        categoryIds,
        storeIds,
        retailerTokens,
        companyTokens,
        textSearch,
        zipcode,
        latitude,
        longitude,
        radius,
        orderBy,
        publisherToken,
      ];
}
